window.requestAnimFrame = (function() {
	return window.requestAnimationFrame    || 
		window.webkitRequestAnimationFrame || 
		window.mozRequestAnimationFrame    ||
		window.msRequestAnimationFrame     || 
		function(callback, element){
			window.setTimeout(callback, 1000 / 60);
		};
})();

var onLoad = function() {
	
	var width = 1;
	var height = 1;
	
	var polygons = [];
	var segments = [];
	
	var mul = 1;
	
	var resetpoly = function() {
		polygons = [
			[[-1,-1],[width+1,-1],[width+1,height+1],[-1,height+1]]
		]
		
		var base = [
			[
				[93,250],[104,235],[122,224],[141,218],[166,218],[243,239],[279,244],
				[308,242],[327,239],[308,177],[280,128],[251,103],[223,90],[202,85],
				[177,66],[163,58],[153,56],[144,59],[121,77],[107,86],[91,89],[108,74],
				[139,50],[154,46],[172,50],[208,75],[228,81],[248,91],[263,100],
				[282,117],[291,127],[307,154],[319,176],[329,208],[338,241],[336,248],
				[313,252],[283,255],[242,251],[167,229],[143,229],[125,233],[107,245],
				[93,250]
			],
			[
				[172,282],[188,270],[198,258],[201,247],[202,234],[190,230],[191,246],
				[187,257],[173,271],[164,259],[157,241],[155,224],[144,224],[145,238],
				[154,262],[164,277],[172,282],[172,282]
			]
		];
		
		var corew = 400, coreh = 350;
		
		var xpos = (width-(corew*mul))/2;
		var ypos = (height-(coreh*mul))/2;
		
		for (var i = 0; i < base.length; ++i) {
			polygons[i+1] = [];
			for (var j = 0, je = base[i].length; j !== je; ++j) {
				polygons[i+1].push([ (base[i][j][0] * mul) + xpos, (base[i][j][1] * mul) + ypos ]);
			}
		}
		
		segments = VisibilityPolygon.convertToSegments(polygons);
	}
	
	var onResize = function(e) {
		width = window.innerWidth;
		height = window.innerHeight;
		
		canvas.width = width;
		canvas.height = height;
		
		resetpoly();
	};
	window.addEventListener('resize', onResize);
	
	var observer_x = 109;
	var observer_y = 109;
	
	var canvas = document.getElementById('c');
	var ctx = canvas.getContext('2d');
	
	onResize();
	
	var observer_t = 0;
	var observe = function() {
		observer_t++;
		
		var period = 300;
		var part = (observer_t % period) / period;
		
		observer_x = Math.sin(part * Math.PI * 2) * (width/2) + (width/2);

		period = 240;
		part = (observer_t % period) / period;
		
		observer_y = Math.cos(part * Math.PI * 2) * (height/2) + (height/2);
		
		period = 600;
		part = (observer_t % period) / period;
		
		mul = Math.sin(part * Math.PI * 2) * 0.75 + 1;
		resetpoly();
	};
	
	var tick = function() {
		observe();
		draw();
		
		requestAnimFrame(tick);
	};
	
	requestAnimFrame(tick);
	
	var draw = function() {	
	
		ctx.clearRect(0, 0, width, height);
		ctx.beginPath();
		ctx.rect(0, 0, width, height);
		ctx.fillStyle = '#333';
		ctx.fill();
		
		var poly = VisibilityPolygon.compute([observer_x, observer_y], segments);
		
		ctx.beginPath();
		ctx.moveTo(poly[0][0], poly[0][1]);
		for (var i = 1; i < poly.length; ++i) {
			ctx.lineTo(poly[i][0], poly[i][1]);
		}
		ctx.fillStyle = "#888888";
		ctx.fill();

		ctx.beginPath();
		ctx.arc(observer_x, observer_y, 5, 0, Math.PI*2, true);
		ctx.fillStyle = "#999";
		ctx.fill();
	};
	
};

window.addEventListener('load', onLoad);

